Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1001)

Unified Diff: src/gpu/glsl/GrGLSLFragmentProcessor.h

Issue 1434313002: Make all GrFragmentProcessors GL independent. (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/glsl/GrGLSLBlend.cpp ('k') | src/gpu/glsl/GrGLSLFragmentProcessor.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/glsl/GrGLSLFragmentProcessor.h
diff --git a/src/gpu/gl/GrGLFragmentProcessor.h b/src/gpu/glsl/GrGLSLFragmentProcessor.h
similarity index 90%
rename from src/gpu/gl/GrGLFragmentProcessor.h
rename to src/gpu/glsl/GrGLSLFragmentProcessor.h
index 311612df7f65329db03ce3f0150cfcf1dff75b29..fa4f043ff73f638233bf8b2f767820608dd80593 100644
--- a/src/gpu/gl/GrGLFragmentProcessor.h
+++ b/src/gpu/glsl/GrGLSLFragmentProcessor.h
@@ -5,8 +5,8 @@
* found in the LICENSE file.
*/
-#ifndef GrGLFragmentProcessor_DEFINED
-#define GrGLFragmentProcessor_DEFINED
+#ifndef GrGLSLFragmentProcessor_DEFINED
+#define GrGLSLFragmentProcessor_DEFINED
#include "glsl/GrGLSLProcessorTypes.h"
#include "glsl/GrGLSLProgramDataManager.h"
@@ -17,11 +17,11 @@ class GrProcessorKeyBuilder;
class GrGLSLFPBuilder;
class GrGLSLCaps;
-class GrGLFragmentProcessor {
+class GrGLSLFragmentProcessor {
public:
- GrGLFragmentProcessor() {}
+ GrGLSLFragmentProcessor() {}
- virtual ~GrGLFragmentProcessor() {
+ virtual ~GrGLSLFragmentProcessor() {
for (int i = 0; i < fChildProcessors.count(); ++i) {
delete fChildProcessors[i];
}
@@ -78,7 +78,7 @@ public:
int numChildProcessors() const { return fChildProcessors.count(); }
- GrGLFragmentProcessor* childProcessor(int index) const {
+ GrGLSLFragmentProcessor* childProcessor(int index) const {
return fChildProcessors[index];
}
@@ -97,18 +97,18 @@ public:
void emitChild(int childIndex, const char* inputColor, EmitArgs& parentArgs);
protected:
/** A GrGLFragmentProcessor instance can be reused with any GrFragmentProcessor that produces
the same stage key; this function reads data from a GrFragmentProcessor and uploads any
uniform variables required by the shaders created in emitCode(). The GrFragmentProcessor
- parameter is guaranteed to be of the same type that created this GrGLFragmentProcessor and
- to have an identical processor key as the one that created this GrGLFragmentProcessor. */
+ parameter is guaranteed to be of the same type that created this GrGLSLFragmentProcessor and
+ to have an identical processor key as the one that created this GrGLSLFragmentProcessor. */
// TODO update this to pass in GrFragmentProcessor
virtual void onSetData(const GrGLSLProgramDataManager&, const GrProcessor&) {}
private:
void internalEmitChild(int, const char*, const char*, EmitArgs&);
- SkTArray<GrGLFragmentProcessor*, true> fChildProcessors;
+ SkTArray<GrGLSLFragmentProcessor*, true> fChildProcessors;
friend class GrFragmentProcessor;
};
« no previous file with comments | « src/gpu/glsl/GrGLSLBlend.cpp ('k') | src/gpu/glsl/GrGLSLFragmentProcessor.cpp » ('j') | no next file with comments »
@@ -97,18 +97,18 @@ public:
void emitChild(int childIndex, const char* inputColor, EmitArgs& parentArgs);
protected:
- /** A GrGLFragmentProcessor instance can be reused with any GrFragmentProcessor that produces
+ /** A GrGLSLFragmentProcessor instance can be reused with any GrFragmentProcessor that produces
the same stage key; this function reads data from a GrFragmentProcessor and uploads any
uniform variables required by the shaders created in emitCode(). The GrFragmentProcessor

Powered by Google App Engine
This is Rietveld 408576698